/*!
 * @file trace.cpp
 * @brief Generic tracing functions for debug or production code.
 *
 * Copyright 2015 (c) Fastec Imaging as an unpublished work.
 * All Rights Reserved.
 *
 * The information contained herein is confidential property of
 * Fastec Imaging. The use, copying, transfer or disclosure of such
 * information is prohibited except by express written agreement
 * with Fastec Imaging.
 */

#include "fas_trace.h"

/**
 * @brief Global Trace Control Word.
 *
 * Trace Points use this Control word, unless local references to traceControl
 * resolve to a different variable (for example one in a local namespace, or
 * class instance).
 */
uint32_t traceControl = TRACE_DEFAULT_MASK;

/**
 * @brief Private implementation for all Trace Points
 *
 * @param fmt
 * @param ap
 */
static void _trace(const char *fmt, va_list ap)
{
    vprintf(fmt, ap);
    printf("\n");
}


void vtrace(const char *fmt, va_list ap)
{
    _trace(fmt, ap);
}

void trace(const char *fmt, ...)
{
    va_list ap;

    va_start(ap, fmt);
    _trace(fmt, ap);
    va_end(ap);
}

Trace::Trace() :
    traceControl(TRACE_DEFAULT_MASK)
{
}

Trace::~Trace()
{
}

void Trace::setTrace(uint32_t t)
{
    traceControl = t;
}

uint32_t Trace::getTrace()
{
    return traceControl;
}
